import 'dart:convert';
import 'package:http/http.dart' as http;

import 'package:f0ckapp/models/mediaitem.dart';
import 'package:f0ckapp/models/mediaitem_detail.dart';

Future<List<MediaItem>> fetchMedia({String? older, String? mode}) async {
  final Uri url = Uri.parse('https://api.f0ck.me/items/get')
    .replace(queryParameters: {
      'mode': mode ?? 'image',
      if (older != null) 'older': older,
    });

  final response = await http.get(url);
  if (response.statusCode == 200) {
    final List<dynamic> jsonList = jsonDecode(response.body);
    return jsonList.map((item) => MediaItem.fromJson(item)).toList();
  } else {
    throw Exception('Fehler beim Abrufen der Medien: ${response.statusCode}');
  }
}

Future<MediaItemDetail> fetchMediaDetail(int itemId) async {
  final Uri url = Uri.parse('https://f0ck.me/api/v2/item/${itemId.toString()}');

  final response = await http.get(url);
  if (response.statusCode == 200) {
    final Map<String, dynamic> jsonResponse = jsonDecode(response.body);
    return MediaItemDetail.fromJson(jsonResponse['rows']);
  } else {
    throw Exception('Fehler beim Abrufen der Media-Details: ${response.statusCode}');
  }
}
